summaryrefslogtreecommitdiff
path: root/unlock_indicator.h
diff options
context:
space:
mode:
Diffstat (limited to 'unlock_indicator.h')
-rw-r--r--unlock_indicator.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/unlock_indicator.h b/unlock_indicator.h
index e679564..acfe768 100644
--- a/unlock_indicator.h
+++ b/unlock_indicator.h
@@ -11,10 +11,11 @@ typedef enum {
} unlock_state_t;
typedef enum {
- STATE_PAM_IDLE = 0, /* no PAM interaction at the moment */
- STATE_PAM_VERIFY = 1, /* currently verifying the password via PAM */
- STATE_PAM_LOCK = 2, /* currently locking the screen */
- STATE_PAM_WRONG = 3 /* the password was wrong */
+ STATE_PAM_IDLE = 0, /* no PAM interaction at the moment */
+ STATE_PAM_VERIFY = 1, /* currently verifying the password via PAM */
+ STATE_PAM_LOCK = 2, /* currently locking the screen */
+ STATE_PAM_WRONG = 3, /* the password was wrong */
+ STATE_I3LOCK_LOCK_FAILED = 4 /* i3lock failed to load */
} pam_state_t;
xcb_pixmap_t draw_image(uint32_t* resolution);